==> qis-2.0.12.tar.gz: qis-2.0.12/qis/perfstats/__init__.py <==


from qis.perfstats.config import (
    FULL_TABLE_COLUMNS,
    PerfParams,
    PerfStat,
    RA_TABLE_COLUMNS,
    RA_TABLE_COMPACT_COLUMNS,
    RegimeData,
    RegimeType,
    ReturnTypes,
    SD_PERF_COLUMNS,
    TRE_TABLE_COLUMNS
)

from qis.perfstats.cond_regression import estimate_cond_regression, get_regime_regression_params

from qis.perfstats.desc_table import DescTableType, compute_desc_table

from qis.perfstats.perf_stats import (
    STANDARD_TABLE_COLUMNS,
    LN_TABLE_COLUMNS,
    LN_BENCHMARK_TABLE_COLUMNS,
    LN_BENCHMARK_TABLE_COLUMNS_SHORT,
    EXTENDED_TABLE_COLUMNS,
    COMPACT_TABLE_COLUMNS,
    BENCHMARK_TABLE_COLUMNS,
    BENCHMARK_TABLE_COLUMNS2,
    compute_avg_max_dd,
    compute_desc_freq_table,
    compute_drawdown,
    compute_drawdown_data,
    compute_drawdown_time_under_water,
    compute_info_ratio_table,
    compute_max_dd,
    compute_performance_table,
    compute_ra_perf_table,
    compute_ra_perf_table_with_benchmark,
    compute_risk_table,
    compute_te_ir_errors,
    compute_time_under_water,
    compute_drawdowns_stats_table
)

from qis.perfstats.regime_classifier import (
    BenchmarkReturnsQuantileRegimeSpecs,
    BenchmarkReturnsQuantilesRegime,
    BenchmarkVolsQuantilesRegime,
    RegimeClassifier,
    VolQuantileRegimeSpecs,
    compute_bnb_regimes_pa_perf_table,
    compute_mean_freq_regimes,
    compute_regime_avg,
    compute_regimes_pa_perf_table
)

from qis.perfstats.returns import (
    adjust_navs_to_portfolio_pa,
    compute_excess_returns,
    compute_grouped_nav,
    compute_net_return,
    compute_num_years,
    compute_pa_excess_returns,
    compute_pa_return,
    compute_returns_dict,
    compute_sampled_vols,
    compute_total_return,
    estimate_vol,
    get_excess_returns_nav,
    get_net_navs,
    log_returns_to_nav,
    portfolio_navs_to_additive,
    portfolio_returns_to_nav,
    prices_at_freq,
    returns_to_nav,
    to_portfolio_returns,
    long_short_to_relative_nav,
    to_returns,
    prices_to_scaled_nav,
    to_total_returns,
    to_zero_first_nonnan_returns,
    df_price_ffill_between_nans,
    to_rolling_returns
)

from qis.perfstats.timeseries_bfill import (
    MergingMethods,
    append_time_series,
    bfill_timeseries,
    df_fill_first_nan_by_cross_median,
    df_price_fill_first_nan_by_cross_median,
    replace_nan_by_median
)

==> qis-2.0.24.tar.gz: qis-2.0.24/qis/perfstats/__init__.py <==


from qis.perfstats.config import (
    FULL_TABLE_COLUMNS,
    PerfParams,
    PerfStat,
    RA_TABLE_COLUMNS,
    RA_TABLE_COMPACT_COLUMNS,
    RegimeData,
    RegimeType,
    ReturnTypes,
    SD_PERF_COLUMNS,
    TRE_TABLE_COLUMNS
)

from qis.perfstats.cond_regression import estimate_cond_regression, get_regime_regression_params

from qis.perfstats.desc_table import DescTableType, compute_desc_table

from qis.perfstats.perf_stats import (
    STANDARD_TABLE_COLUMNS,
    LN_TABLE_COLUMNS,
    LN_BENCHMARK_TABLE_COLUMNS,
    LN_BENCHMARK_TABLE_COLUMNS_SHORT,
    EXTENDED_TABLE_COLUMNS,
    COMPACT_TABLE_COLUMNS,
    BENCHMARK_TABLE_COLUMNS,
    BENCHMARK_TABLE_COLUMNS2,
    compute_avg_max_dd,
    compute_desc_freq_table,
    compute_rolling_drawdowns,
    compute_rolling_drawdown_time_under_water,
    compute_info_ratio_table,
    compute_max_dd,
    compute_performance_table,
    compute_ra_perf_table,
    compute_ra_perf_table_with_benchmark,
    compute_risk_table,
    compute_te_ir_errors,
    compute_drawdowns_stats_table
)

from qis.perfstats.regime_classifier import (
    BenchmarkReturnsQuantileRegimeSpecs,
    BenchmarkReturnsQuantilesRegime,
    BenchmarkVolsQuantilesRegime,
    RegimeClassifier,
    VolQuantileRegimeSpecs,
    compute_bnb_regimes_pa_perf_table,
    compute_mean_freq_regimes,
    compute_regime_avg,
    compute_regimes_pa_perf_table
)

from qis.perfstats.returns import (
    adjust_navs_to_portfolio_pa,
    compute_excess_returns,
    compute_grouped_nav,
    compute_net_return,
    compute_num_years,
    compute_pa_excess_returns,
    compute_pa_return,
    compute_returns_dict,
    compute_sampled_vols,
    compute_total_return,
    estimate_vol,
    get_excess_returns_nav,
    get_net_navs,
    log_returns_to_nav,
    portfolio_navs_to_additive,
    portfolio_returns_to_nav,
    prices_at_freq,
    returns_to_nav,
    to_portfolio_returns,
    long_short_to_relative_nav,
    to_returns,
    prices_to_scaled_nav,
    to_total_returns,
    to_zero_first_nonnan_returns,
    df_price_ffill_between_nans,
    to_rolling_returns
)

from qis.perfstats.timeseries_bfill import (
    MergingMethods,
    append_time_series,
    bfill_timeseries,
    df_fill_first_nan_by_cross_median,
    df_price_fill_first_nan_by_cross_median,
    replace_nan_by_median
)
